Package: SOMbrero
Title: SOM Bound to Realize Euclidean and Relational Outputs
Version: 1.5.0
Date: 2025-10-06
Authors@R: c(person("Nathalie", "Vialaneix", role = c("aut", "cre"), 
                    email = "nathalie.vialaneix@inrae.fr", 
                    comment = c(ORCID = "0000-0003-1156-0639")),
             person("Elise", "Maigne", role = "aut", 
                    email = "elise.maigne@inrae.fr"),
             person("Jerome", "Mariette", role = "aut", 
                    email = "jerome.mariette@inrae.fr"),
             person("Madalina", "Olteanu", role = "aut", 
                    email = "olteanu@ceremade.dauphine.fr"),
             person("Fabrice", "Rossi", role = "aut", 
                    email = "fabrice.rossi@apiacoa.org"),
             person("Laura", "Bendhaiba", role = "ctb", 
                    email = "laurabendhaiba@gmail.com"),
             person("Julien", "Boelaert", role = "ctb", 
                    email = "julien.boelaert@gmail.com"))
Maintainer: Nathalie Vialaneix <nathalie.vialaneix@inrae.fr>
Description: The stochastic (also called on-line) version of the Self-Organising
             Map (SOM) algorithm is provided. Different versions of the
             algorithm are implemented, for numeric and relational data and for
             contingency tables as described, respectively, in Kohonen (2001)
             <isbn:3-540-67921-9>, Olteanu & Villa-Vialaneix (2005)
             <doi:10.1016/j.neucom.2013.11.047> and Cottrell et al (2004)
             <doi:10.1016/j.neunet.2004.07.010>. The package also contains many
             plotting features (to help the user interpret the results), can 
             handle (and impute) missing values and is delivered with a 
             graphical user interface based on 'shiny'.
BugReports: https://github.com/tuxette/SOMbrero/issues
URL: https://forge.inrae.fr/nathalie.villa-vialaneix/sombrero,
        http://sombrero.clementine.wf/
Depends: R (>= 3.1.0), igraph (>= 1.0), markdown
Imports: scatterplot3d, shiny, grDevices, graphics, stats, ggplot2,
        ggwordcloud, metR, interp, rlang
Suggests: testthat, rmarkdown, knitr, hexbin, shinycssloaders, shinyBS,
        shinyjs, shinyjqui, RColorBrewer
License: GPL (>= 2)
Repository: CRAN
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.2
Language: en-US
NeedsCompilation: no
Packaged: 2025-10-06 15:28:38 UTC; nathalie
Author: Nathalie Vialaneix [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1156-0639>),
  Elise Maigne [aut],
  Jerome Mariette [aut],
  Madalina Olteanu [aut],
  Fabrice Rossi [aut],
  Laura Bendhaiba [ctb],
  Julien Boelaert [ctb]
Date/Publication: 2025-10-06 16:00:07 UTC
Built: R 4.6.0; ; 2026-04-26 15:15:11 UTC; unix
