# Generated by roxygen2: do not edit by hand

S3method(cutree,default)
S3method(cutree,somSC)
S3method(impute,somRes)
S3method(plot,myGrid)
S3method(plot,somRes)
S3method(plot,somSC)
S3method(predict,somRes)
S3method(print,myGrid)
S3method(print,paramSOM)
S3method(print,somRes)
S3method(print,somSC)
S3method(projectIGraph,somRes)
S3method(projectIGraph,somSC)
S3method(protoDist,somRes)
S3method(quality,somRes)
S3method(summary,myGrid)
S3method(summary,paramSOM)
S3method(summary,somRes)
S3method(summary,somSC)
S3method(superClass,somRes)
S3method(trainSOM,data.frame)
S3method(trainSOM,dist)
S3method(trainSOM,kernel)
S3method(trainSOM,matrix)
export(cutree)
export(impute)
export(initGrid)
export(initSOM)
export(projectIGraph)
export(protoDist)
export(quality)
export(sombreroGUI)
export(superClass)
export(trainSOM)
import(ggplot2)
import(igraph)
import(markdown)
importFrom(ggwordcloud,geom_text_wordcloud)
importFrom(grDevices,hcl)
importFrom(grDevices,trans3d)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(interp,interp)
importFrom(metR,geom_contour_fill)
importFrom(rlang,.data)
importFrom(scatterplot3d,scatterplot3d)
importFrom(stats,aggregate)
importFrom(stats,aov)
importFrom(stats,as.dist)
importFrom(stats,chisq.test)
importFrom(stats,cmdscale)
importFrom(stats,cutree)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pf)
importFrom(stats,princomp)
importFrom(stats,quantile)
importFrom(stats,rect.hclust)
importFrom(stats,reshape)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,packageVersion)
