---
title: "SOMbrero Package description"
date: "`r format(Sys.time(), '%d %B, %Y')`"
output:
  html_document:
    self_contained: true
    theme: journal
    toc: yes
    toc_float:
      collapsed: no
vignette: >
  %\VignetteIndexEntry{The SOMbrero package}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

![](./sombrero.png)

## Package description

```SOMbrero``` ('Self Organizing Maps Bound to Realize Euclidean and Relational 
Outputs') implements several variants of the stochastic Self-Organising Map
algorithm and is able to handle numeric and non numeric data sets (contingency
tables, graphs or any 'relational' data described by a dissimilarity matrix).

See ```help(SOMbrero)``` for further details.

Information on 
[grids in SOMbrero](http://sombrero.clementine.wf/articles/b-doc-grids.html)

### Numeric SOM

The numeric SOM is illustrated on the well-known ```iris``` data set. This data
describe iris flowers with 4 numeric variables (```Sepal.Length```, 
```Sepal.Width```, ```Petal.Length``` and ```Petal.Width```) and a fifth 
variable (not used to train the SOM) is the flower species. This example is 
processed in the 
[numeric SOM guide](http://sombrero.clementine.wf/articles/c-doc-numericSOM.html).


### Contingency tables

The SOM algorithm provided by the package ```SOMbrero``` can also handle some
non-numeric data. First, data described by contingency tables, which can be 
processed using the 'korresp' algorithm (see Cottrell et al., 2004, 2005). This 
case is illustrated on the ```presidentielles2002``` dataset, which contains the
number of votes in the first round of the French 2002 presidential election, for 
each of the French administrative departments (row variables) and each of the
candidates (column variables). This example is used in the
[korresp user guide](http://sombrero.clementine.wf/articles/d-doc-korrespSOM.html).


### Dissimilarity matrices

Data described by a dissimilarity matrix can also be processed by ```SOMbrero```
as described in Olteanu et al., 2015a. This case is illustrated on a data set
extracted from the novel ```Les Miserables```, written by the French author 
Victor Hugo and published during the XIXth century. This dataset provides a
dissimilarity matrix between the characters of the novel, based on the length
of shortest paths in a network defined from the novel. This example is provided
in the 
[relational user guide](http://sombrero.clementine.wf/articles/e-doc-relationalSOM.html).


For those who have an **R** developer soul, and who want to help improve this 
package, the following picture provides an overview the current function
dependencies of the package:

![](./dependencies.png)



### Session information

This vignette has been computed with the following environment:
```{r sessionInfo}
sessionInfo()
```

